'use client'

import React, { useEffect, useRef } from 'react'
import { motion, useAnimation, useInView } from 'framer-motion'
import Image from 'next/image'

const CustomTextSection: React.FC = () => {
  const controls = useAnimation()
  const ref = useRef(null)
  const isInView = useInView(ref, { once: true, threshold: 0.2 })

  useEffect(() => {
    if (isInView) {
      controls.start('visible')
    }
  }, [controls, isInView])

  const containerVariants = {
    hidden: { opacity: 0 },
    visible: {
      opacity: 1,
      transition: {
        staggerChildren: 0.2
      }
    }
  }

  const itemVariants = {
    hidden: { opacity: 0, y: 20 },
    visible: {
      opacity: 1,
      y: 0,
      transition: { duration: 0.5 }
    }
  }

  return (
    <section ref={ref} className="cts-section bg-[#1e2a3a] py-20 px-4">
      <div className="cts-container max-w-6xl mx-auto flex flex-col md:flex-row items-center justify-between">
        <motion.div
          className="cts-text-content mb-10 md:mb-0 md:mr-10"
          variants={containerVariants}
          initial="hidden"
          animate={controls}
        >
          <motion.h2 
            className="cts-title text-4xl md:text-5xl lg:text-6xl font-bold text-white mb-4"
            variants={itemVariants}
          >
            Discover, <span className="cts-underline-green relative">
              Sell
              <svg className="absolute -bottom-1 left-0 w-full h-2" viewBox="0 0 100 10" preserveAspectRatio="none">
                <path d="M0 5 Q 50 10, 100 5" stroke="#4ade80" strokeWidth="2" fill="none" />
              </svg>
            </span>
          </motion.h2>
          <motion.h2 
            className="cts-title text-4xl md:text-5xl lg:text-6xl font-bold text-white mb-4"
            variants={itemVariants}
          >
            & Collect <span className="cts-underline-green relative">
              Rare
              <svg className="absolute -bottom-1 left-0 w-full h-2" viewBox="0 0 100 10" preserveAspectRatio="none">
                <path d="M0 5 Q 50 10, 100 5" stroke="#4ade80" strokeWidth="2" fill="none" />
              </svg>
            </span>
          </motion.h2>
          <motion.h2 
            className="cts-title text-4xl md:text-5xl lg:text-6xl font-bold text-white"
            variants={itemVariants}
          >
            <span className="cts-underline-red relative">
              NFTs
              <svg className="absolute -bottom-1 left-0 w-full h-2" viewBox="0 0 100 10" preserveAspectRatio="none">
                <path d="M0 5 Q 50 10, 100 5" stroke="#ef4444" strokeWidth="2" fill="none" />
              </svg>
            </span>
          </motion.h2>
        </motion.div>
        <motion.div
          className="cts-image-container"
          variants={itemVariants}
          initial="hidden"
          animate={controls}
          whileHover={{ scale: 1.05 }}
        >
          <div className="cts-image-wrapper bg-white rounded-full p-4 shadow-lg">
            <Image
              src="/placeholder.svg?height=200&width=200"
              alt="Nest Thermostat"
              width={200}
              height={200}
              className="cts-image rounded-full"
            />
          </div>
        </motion.div>
      </div>
    </section>
  )
}

export default CustomTextSection